@@ -13,10 +13,7 @@ from typeguard import check_type
 import ros_cdk_assembly_schema._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@alicloud/ros-cdk-cxapi",
-    "1.0.12",
-    __name__[0:-6],
-    "ros-cdk-cxapi@1.0.12.jsii.tgz",
+    "@alicloud/ros-cdk-cxapi", "1.9.0", __name__[0:-6], "ros-cdk-cxapi@1.9.0.jsii.tgz"
 )
 
 __all__ = [
